// ListCtrlData.cpp: implementation of the CListCtrlData class.
// Copyright (c) 2015 by David Wincelberg
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "ListCtrlData.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

// Action:	Sets the size of the string array to match the number
//			of columns in the list control.
CListCtrlData::CListCtrlData (CListCtrl* pListCtrl, LPARAM lParam /* = 0 */)
{
	CHeaderCtrl* pHeader = pListCtrl->GetHeaderCtrl();
	m_nCols = __max (pHeader->GetItemCount(), 0);
	m_saCols.SetSize (m_nCols);

	m_lParam = lParam;
}	// CListCtrlData


// Action:	Sets the size of the string array to match the supplied number.
CListCtrlData::CListCtrlData (int nCols /* = 0 */, LPARAM lParam /* = 0 */)
{
	m_nCols  = __max (nCols, 0);
	m_saCols.SetSize (m_nCols);
	m_lParam = lParam;
}	// CListCtrlData


// Action:	Sets the attributes based on the input string array.
CListCtrlData::CListCtrlData (CStringArray& saCols, LPARAM lParam /* = 0 */)
{
	m_nCols = __max (saCols.GetSize(), 0);
	m_saCols.SetSize (m_nCols);

	for (int n = 0;  n < m_nCols;  ++n) {
		m_saCols.SetAt (n, saCols.GetAt (n));
	}

	m_lParam = lParam;
}	// CListCtrlData


CListCtrlData::~CListCtrlData()
{

}

//////////////////////////////////////////////////////////////////////
// Operations
//////////////////////////////////////////////////////////////////////

// Action:	Sets the string at the specified position.
void CListCtrlData::SetAt (int nCol, LPCTSTR newElement)
{
	if (0 <= nCol && nCol < m_nCols && newElement != nullptr)
		m_saCols.SetAt (nCol, newElement);
}	// SetAt


// Action:	Retrieves the string at the specified position.
// Note:	This virtual function may be replaced or supplemented as needed.
CString CListCtrlData::GetAt (int nCol) const
{
	if (0 <= nCol && nCol < m_nCols)
		return m_saCols.GetAt (nCol);
	else
		return _T("");
}	// GetAt


// Action:	Copies the data members from another object.
CListCtrlData& CListCtrlData::operator= (const CListCtrlData& other)
{
	if (&other != this) {
		int nSize = other.m_saCols.GetSize();

		if (nSize > 0) {
			nSize = __min (nSize, m_nCols);

			for (int n = 0;  n < nSize;  ++n) {
				m_saCols.SetAt (n, other.m_saCols.GetAt (n));
			}
		}

		m_lParam = other.m_lParam;
	}

	return *this;
}	// operator=
