// ListCtrlOrder.cpp: implementation of the CListCtrlOrder class.
// Copyright (c) 2016 by David Wincelberg
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "ListCtrlOrder.h"

#include "ListCtrlData.h"
#include "StringOrder.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

// Note:	These parameters relate to the Strategy and Flyweight patterns.
CListCtrlOrder::CListCtrlOrder (CStringOrder* pStringOrder /* = nullptr */,
								bool bHandleDelete /* = true */)
{
	m_pStringOrder  = (pStringOrder == nullptr ? new CStringOrder() : pStringOrder);
	m_bHandleDelete = bHandleDelete;
	m_nCol          = 0;
	m_bReverse      = false;
}	// CListCtrlOrder


CListCtrlOrder::~CListCtrlOrder()
{
	if (m_bHandleDelete)
		delete m_pStringOrder;
}

//////////////////////////////////////////////////////////////////////
// Operations
//////////////////////////////////////////////////////////////////////

// Action:	Replaces the string-order object.
//			Deletes the old one unless m_bHandleDelete is false.
// Note:	This relates to the Strategy and Flyweight patterns.
void CListCtrlOrder::SetStringOrder (CStringOrder* pStringOrder,
									 bool bHandleDelete /* = true */)
{
	if (pStringOrder == nullptr)
		return;

	if (m_bHandleDelete)
		delete m_pStringOrder;

	m_pStringOrder  = pStringOrder;
	m_bHandleDelete = bHandleDelete;
}	// SetStringOrder


// Action:	Sets the variables that are needed by Compare.
void CListCtrlOrder::SetValues (int nCol, bool bReverse)
{
	m_nCol     = nCol;
	m_bReverse = bReverse;
}	// SetValues


// Action:	Compares two strings using the supplied string order.
// Note:	This virtual function may be replaced for custom ordering.
int CListCtrlOrder::Compare (LPARAM lParam1, LPARAM lParam2)
{
	if (!ValidStringOrder())
		return 0;

	CListCtrlData* pData1 = reinterpret_cast<CListCtrlData*> (lParam1);
	CListCtrlData* pData2 = reinterpret_cast<CListCtrlData*> (lParam2);

	int nResult = GetStringOrder()->CompareStrings (pData1->GetAt (m_nCol),
		pData2->GetAt (m_nCol));

	if (m_bReverse)
		return -nResult;
	else
		return +nResult;
}	// Compare
